<?php
/*
Plugin Name: Bulk Product Creator
Description: Плагин для массового создания товаров WooCommerce.
Version: 1.0
Author: Alexandr Sazonov
*/

if (!defined('ABSPATH')) {
    exit; // Защита от прямого доступа к файлу.
}

// Хук для добавления страницы настроек в меню админки.
add_action('admin_menu', 'bpc_add_admin_menu');

function bpc_add_admin_menu() {
    add_menu_page(
        'Bulk Product Creator', // Название страницы
        'Bulk Product Creator', // Название меню
        'manage_options',       // Права доступа
        'bulk-product-creator', // Уникальный слаг
        'bpc_settings_page',    // Функция отображения страницы
        'dashicons-cart',       // Иконка меню
        20                      // Позиция в меню
    );
}

// Функция отображения страницы настроек.
function bpc_settings_page() {
    ?>
    <div class="wrap">
        <h1>Bulk Product Creator</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('bpc_settings_group');
            do_settings_sections('bulk-product-creator');
            submit_button();
            ?>
        </form>
        <a href="<?php echo admin_url('admin.php?page=bulk-product-creator-create'); ?>" class="button button-primary">Создать товары</a>
    </div>
    <?php
}

// Хук для регистрации настроек.
add_action('admin_init', 'bpc_settings_init');

function bpc_settings_init() {
    register_setting('bpc_settings_group', 'bpc_settings');

    add_settings_section(
        'bpc_settings_section',
        'Настройки создания товаров',
        'bpc_settings_section_callback',
        'bulk-product-creator'
    );

    add_settings_field(
        'bpc_product_name',
        'Имя продукта',
        'bpc_product_name_render',
        'bulk-product-creator',
        'bpc_settings_section'
    );

    add_settings_field(
        'bpc_product_image',
        'URL изображения продукта',
        'bpc_product_image_render',
        'bulk-product-creator',
        'bpc_settings_section'
    );

    add_settings_field(
        'bpc_product_description',
        'Описание продукта',
        'bpc_product_description_render',
        'bulk-product-creator',
        'bpc_settings_section'
    );

    add_settings_field(
        'bpc_product_price',
        'Цена продукта',
        'bpc_product_price_render',
        'bulk-product-creator',
        'bpc_settings_section'
    );

    add_settings_field(
        'bpc_product_quantity',
        'Количество создаваемых товаров',
        'bpc_product_quantity_render',
        'bulk-product-creator',
        'bpc_settings_section'
    );

    add_settings_field(
        'bpc_product_category',
        'Категория продукта',
        'bpc_product_category_render',
        'bulk-product-creator',
        'bpc_settings_section'
    );
}

function bpc_settings_section_callback() {
    echo 'Введите данные для массового создания товаров.';
}

function bpc_product_name_render() {
    $options = get_option('bpc_settings');
    ?>
    <input type="text" name="bpc_settings[bpc_product_name]" value="<?php echo isset($options['bpc_product_name']) ? esc_attr($options['bpc_product_name']) : ''; ?>" />
    <?php
}

function bpc_product_image_render() {
    $options = get_option('bpc_settings');
    ?>
    <input type="text" name="bpc_settings[bpc_product_image]" value="<?php echo isset($options['bpc_product_image']) ? esc_attr($options['bpc_product_image']) : ''; ?>" placeholder="Введите URL изображения" />
    <?php
}

function bpc_product_description_render() {
    $options = get_option('bpc_settings');
    ?>
    <textarea name="bpc_settings[bpc_product_description]"><?php echo isset($options['bpc_product_description']) ? esc_textarea($options['bpc_product_description']) : ''; ?></textarea>
    <?php
}

function bpc_product_price_render() {
    $options = get_option('bpc_settings');
    ?>
    <input type="number" step="0.01" name="bpc_settings[bpc_product_price]" value="<?php echo isset($options['bpc_product_price']) ? esc_attr($options['bpc_product_price']) : ''; ?>" />
    <?php
}

function bpc_product_quantity_render() {
    $options = get_option('bpc_settings');
    ?>
    <input type="number" name="bpc_settings[bpc_product_quantity]" value="<?php echo isset($options['bpc_product_quantity']) ? esc_attr($options['bpc_product_quantity']) : ''; ?>" />
    <?php
}

function bpc_product_category_render() {
    $options = get_option('bpc_settings');
    $categories = get_terms(array(
        'taxonomy' => 'product_cat',
        'hide_empty' => false,
    ));
    ?>
    <select name="bpc_settings[bpc_product_category]">
        <?php
        foreach ($categories as $category) {
            echo '<option value="' . esc_attr($category->term_id) . '" ' . selected($options['bpc_product_category'], $category->term_id, false) . '>' . esc_html($category->name) . '</option>';
        }
        ?>
    </select>
    <?php
}


// Хук для добавления кнопки "Создать товары" на странице настроек.
add_action('admin_menu', 'bpc_add_create_products_button');

function bpc_add_create_products_button() {
    add_submenu_page(
        null, // Нет родительского меню
        'Создать товары', // Название страницы
        'Создать товары', // Название меню
        'manage_options', // Права доступа
        'bulk-product-creator-create', // Уникальный слаг
        'bpc_create_products' // Функция отображения страницы
    );
}

// Функция отображения страницы "Создать товары".
function bpc_create_products() {
    if (!current_user_can('manage_options')) {
        return;
    }

    // Получение данных из настроек
    $options = get_option('bpc_settings');
    $product_name = $options['bpc_product_name'];
    $product_image = $options['bpc_product_image'];
    $product_description = $options['bpc_product_description'];
    $product_price = $options['bpc_product_price'];
    $product_quantity = $options['bpc_product_quantity'];
    $product_category = $options['bpc_product_category'];

    // Создание товаров
    for ($i = 1; $i <= $product_quantity; $i++) {
        $new_product = array(
            'post_title' => $product_name . '-' . $i,
            'post_content' => $product_description,
            'post_status' => 'publish',
            'post_type' => 'product'
        );

        $product_id = wp_insert_post($new_product);

        if ($product_id) {
            // Установка цены
            update_post_meta($product_id, '_regular_price', $product_price);
            update_post_meta($product_id, '_price', $product_price);

            // Установка изображения
            if ($product_image) {
                $image_id = bpc_get_image_id_by_url($product_image);
                if ($image_id) {
                    set_post_thumbnail($product_id, $image_id);
                } else {
                    // Загружаем изображение по URL и присваиваем его продукту
                    $upload = media_sideload_image($product_image, $product_id, null, 'id');
                    if (!is_wp_error($upload)) {
                        set_post_thumbnail($product_id, $upload);
                    }
                }
            }

            // Установка категории
            if ($product_category) {
                wp_set_post_terms($product_id, array($product_category), 'product_cat');
            }
        }
    }

    echo '<div class="wrap"><h1>Товары созданы!</h1><a href="' . admin_url('admin.php?page=bulk-product-creator') . '">Назад к настройкам</a></div>';
}

// Функция для получения ID изображения по URL
function bpc_get_image_id_by_url($url) {
    global $wpdb;
    $attachment = $wpdb->get_col($wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE guid='%s';", $url ));
    return isset($attachment[0]) ? $attachment[0] : false;
}
?>